# Skylark

*Alauda arvensis* is a common and charismatic species of agricultural landscapes.
This animal model is one component of the [`nature`](architecture.html) submodel of Persefone.jl.

The  model  description follows  the  ODD  (Overview,  Design  concepts, Details)  protocol  (Grimm  et  al.,  [2006](https://doi.org/10.1016/j.ecolmodel.2006.04.023); [2010](https://doi.org/10.1016/j.ecolmodel.2010.08.019); [2020](https://doi.org/10.18564/jasss.4259)):


## 1. Purpose

The purpose of this animal model is to simulate the abundance and distribution of a population of
*Alauda arvensis* in response to farm management in Central European agricultural landscapes.

## 2. Entities, state variables, and scales

### 2.1 Landscape

The [simulated landscape](gis.html) consists of a grid of pixels with a resolution of 10m and
can have an extent of 20km²-200km² (approximately; depending on the chosen input map).
Each pixel is assigned a land cover class. It may also be associated with a farm plot,
in which case it will contain information about the type and growth stage of the crop
planted here. [Farm management](management.html) determines which crops are grown when, and 
when disturbance (e.g. mowing, harvesting, tillage) takes place.

### 2.2 Animals

The simulated individuals (a.k.a. agents) are mature [skylarks](species.html#Skylark). Each skylark 
is characterised by the following variables:

- `ID` A unique identifier for this individual, which can be used to link it to its parents
  and its offspring.

- `sex` Male or female.

- `phase` The individual's current stage in the annual/life cycle. May be one of: `migration`, 
  `nonbreeding`, `territorysearch`, `occupation`, `matesearch`, `nesting`, `breeding`.

- `position` The individual's position in the simulated landscape.

- `mate` The ID of the individual with which this individual has mated this year, if any.

- `territory` A list of coordinates of the positions in the landscape that this individual
  claims as its nesting and feeding territory.
  
- `nest` A coordinate giving the location of the currently active nest.

- `clutch` The number of juvenile (i.e. not yet independent) skylarks that this individual is
  currently raising.


## 3. Process overview and scheduling

The simulation proceeds in time steps of one day. Every day, each individual executes the function
associated with their current life phase:

- `migration`: The individual is held in a separate data structure (apart from the model landscape)
  and does nothing until its return date is reached. Then, it is re-introduced to the landscape
  and assigned the phase `territorysearch` (for males) or `matesearch` (for females).
  
- `territorysearch`: Males return first from migration. If they already have a territory from a
  previous year, they return to this. Otherwise, they move randomly through the landscape until
  they find a contiguous territory that satisfies their habitat requirements. Once a male has a
  territory, it changes its phase to `occupation`.
  
- `matesearch`: Females return later than males from their winter migration. If they already had
  a partner the previous year, they have a given probability of remaining with this partner.
  Otherwise, they move randomly through the landscape, looking for a male with a territory and
  without a partner. Once the female has a partner, it changes its phase to `nesting`.

If an individual fails to find a territory or a mate, it changes its phase to `nonbreeding` once the
breeding season is over.

- `occupation`: The male moves at random about its territory until the breeding season is over.
  Then it changes its phase to `nonbreeding`. (*Note:* Skylark males actively help with feeding
  their chicks. However, feeding is only modelled indirectly here, through the process of habitat
  selection when the male forms its territory - see section 4.1.)
  
- `nesting`: The female selects a suitable location within the male's territory for the nest.
  Building the nest and laying eggs takes a number of days, during which she does nothing else.
  Then, she changes her phase to `breeding`.
  
- `breeding`: The female checks for mortality. The probability of brood loss varies with the age
  of the clutch and the nesting habitat. If and when the chicks reach independence (30 days after
  hatching), they are instantiated as new individuals in the `nonbreeding` phase.
  
If a nest fails due to predation or disturbance, or a brood leaves the nest successfully, the
female resets her phase to `nesting` and begins again if the breeding season is not yet over.
If it is, she changes her phase to `nonbreeding`.

- `nonbreeding`: Non-breeding mature birds move randomly around the landscape, keeping close
  to other individuals (flocking behaviour). Once their individual migration date is reached,
  they are removed from the landscape until the following year (see above). Mature birds have
  a mortality probability for their first summer, and others thereafter for each winter.

## 4. Design concepts

### 4.1 Basic principles

This model assumes that the two most important drivers of skylark distribution and abundance
are **habitat availability** and **juvenile mortality** (see literature below). The factors 
and processes affecting these are therefore given the most attention in the model, while other 
factors and processes are only included superficially, indirectly, or not at all. Specifically, 
this means that the phases `territorysearch`, `nesting`, and `breeding` are the most relevant 
and detailed parts of the model, as these determine the selection of habitat and the survival of 
offspring.

Furthermore, the model concentrates on predation and anthropogenic disturbance (through management
actions such as mowing) as the main causes of juvenile mortality. Other causes, such as hunger
or bad weather, are currently ignored as they are usually not significant.

The focus on habitat availability and juvenile mortality opens up two avenues by which agricultural
management influences skylark populations. First, the farmers' choice of crops and date of sowing
determines the quality of the habitat when skylarks select a territory. (For example, unlike summer
grain, winter grain is already so high and dense in spring that it is generally avoided for nesting.)
Secondly, the frequency and timing of management actions (especially mowing) is a major cause of
brood loss. This means that there are direct causal links between agriculture and population trends.

Concentrating on these two drivers allows the rest of the model to be kept simple, reducing both the
scientific complexity and computational costs. Thus, foraging movement (both during and after the
breeding season) can be ignored or represented as random movement, as it does not directly impact
either of the drivers. Likewise, chick growth and winter migration are represented very simply.

### 4.2 Emergence

Multiple patterns emerge from the basic principles outlined above. The most important are listed here:

- **Territory size and population density:** The model assumes that skylarks occupy only as much
  area as they need to satisfy their nesting and foraging requirements, and that population size is
  limited by the amount of available habitat. This means that territories in high-quality habitat 
  are smaller than in low-quality habitat. Scaling up, this leads to a pattern whereby population 
  densities are highest in open landscapes with a diversity of crops, grassland, semi-natural habitat,
  and lower in landscapes with low habitat diversity or many woody features.
  
- **Ecological traps:** Jenny (1990) describes a strong ecological trap effect whereby skylarks avoid
  winter grain crops, preferentially nesting in more open grassland sites. However, the mowing
  frequency associated with modern agriculture means that nest loss in grassland is almost assured,
  since there is insufficient time between two mowing dates to raise a brood. This means that landscape
  composition leads skylarks to breed in habitats that have a high mortality, resulting in population
  declines.


### 4.3 Adaptation

In the model, skylarks primarily adapt to their surroundings by choosing suitable territories.
These are chosen by evaluating the quality of surrounding habitats for breeding and foraging, 
and occupying as much area as needed to satisfy requirements (see section 7.1).

### 4.4 Objectives

Skylarks' main objective in the model is to have sufficient habitat available to raise a brood.
Habitat quality is calculated as a function of habitat type, vegetation height, vegetation cover,
and distance to vertical structures (see section 7.1).

### 4.5 Learning

The model includes no learning by individuals.

### 4.6 Prediction

The model includes no predictions by individuals.

### 4.7 Sensing

Skylarks can perceive the landscape structure in a given radius around them (habitat type,
vegetation height and cover). They can also see nearby conspecifics and are aware of the territories
claimed by other individuals. When mating, they recognise whether another individual already has a
mate, and mated individuals share information about their territory and brood status.

### 4.8 Interaction

The model includes two direct forms of interaction. First, during mating, females move around the
landscape looking for males who have a territory but no mate yet. Once they have found one, the
two individuals set each other as their mate. Secondly, after the breeding seasons, individuals
move around the landscape, keeping close to other individuals in their vicinity (flocking behaviour).

There are also indirect interactions, in that there is a competition for habitat (territory that has
been claimed by one male cannot be occupied by another) and males (males that have mated with one
female will not mate with another in the same season).

### 4.9 Stochasticity

Stochasticity is used when modelling mortality and movement. Predation mortality is modelled as an 
age- and habitat-dependent probability, while migration mortality is a simple probability. Dispersal 
movement (when searching for a territory or a mate) is modelled as a random walk, as it is assumed 
that skylarks are not significantly impeded in their long-range movement by habitats that are 
unsuitable for foraging or nesting. Foraging movement by the male and by non-breeding individuals is 
also random, as it is desirable to show movement (to help model analysis) but unimportant to model 
this exactly.

### 4.10 Collectives

After the breeding season, skylarks move around in loose agglomerations (flocking behaviour). However,
this has no relevant ecological effect.

### 4.11 Observation

*TODO*

## 5. Initialisation

At the beginning of a model run, pairs of skylarks are created on grassland and agricultural land,
keeping a distance of 60m to vertical structures and allowing each pair approximately 3ha of
suitable habitat (an average territory size in agricultural landscapes).

For details, see the [source code](https://git.idiv.de/persefone/persefone-model/-/blob/master/src/nature/species/skylark.jl?ref_type=heads) and the associated [documentation](nature.html#populations.jl).

## 6. Input data

The general input to Persefone (i.e. land use maps and weather data) is described [here](gis.html).

The following extract from the [source code](https://git.idiv.de/persefone/persefone-model/-/blob/master/src/nature/species/skylark.jl?ref_type=heads)
lists the species parameters and values used by the Skylark model, based on the literature cited below:

```julia
@species Skylark begin
    const movementrange::Length = 500m #XXX arbitrary
    const visionrange::Length = 200m #XXX arbitrary
    
    const eggtime::Int64 = 11 # days from laying to hatching
    const nestlingtime::Int64 = 9 # days from hatching to leaving nest
    const fledglingtime::Int64 = 21 # days from leaving the nest to independence

    #XXX predation mortality should be habitat-dependent
    const eggpredationmortality::Float64 = 0.03 # per-day egg mortality from predation
    const nestlingpredationmortality::Float64 = 0.03 # per-day nestling mortality from predation
    const fledglingpredationmortality::Float64 = 0.01 # per-day fledgling mortality from predation
    const firstyearmortality::Float64 = 0.38 # total mortality in the first year after independence
    const migrationmortality::Float64 = 0.33 # chance of dying during the winter

    const minimumterritory = 5000m² # size of territory under ideal conditions
    const mindistancetoedge = 60m # minimum distance of habitat to vertical structures
    const maxforageheight = 50cm # maximum preferred vegetation height for foraging
    const maxforagecover = 0.7 # maximum preferred vegetation cover for foraging
    const nestingheight = (15cm, 25cm) # min and max preferred vegetation height for nesting
    const nestingcover = (0.2, 0.5) # min and max preferred vegetation cover for nesting

    const matefaithfulness = 0.5 # chance of a female retaining her previous partner
    const nestingbegin::Tuple{Int64,Int64} = (April, 10) # begin nesting in the middle of April
    const nestbuildingtime::UnitRange{Int64} = 4:5 # 4-5 days needed to build a nest (doubled for first nest)
    const eggsperclutch::UnitRange{Int64} = 2:5 # eggs laid per clutch
    const nestingend::Int64 = July # last month of nesting
end
```

## 7. Submodels

### 7.1 Territory formation

*TODO*

### 7.2 Juvenile mortality

*TODO*

## 8. References

- Bauer, H.-G., Bezzel, E., & Fiedler, W. (Eds.). (2012). Das Kompendium
  der Vögel Mitteleuropas: Ein umfassendes Handbuch zu Biologie, Gefährdung
  und Schutz (Einbändige Sonderausg. der 2., vollständig überarb. und erw.
  Aufl. 2005). AULA-Verlag

- Delius, J. D. (1965). A Population Study of Skylarks Alauda Arvensis.
  [Ibis, 107(4), 466–492.](https://doi.org/10.1111/j.1474-919X.1965.tb07332.x)

- Donald et al. (2002). Survival rates, causes of failure and productivity
  of Skylark Alauda arvensis nests on lowland farmland. 
  [Ibis, 144(4), 652–664.](https://doi.org/10.1046/j.1474-919X.2002.00101.x)

- Glutz von Blotzheim, Urs N. (Ed.). (1985). Handbuch der Vögel Mitteleuropas.
  Bd. 10. Passeriformes (Teil 1) 1. Alaudidae - Hirundidae. AULA-Verlag, Wiesbaden.
  ISBN 3-89104-019-9

- Jenny, M. (1990). Territorialität und Brutbiologie der Feldlerche Alauda
  arvensis in einer intensiv genutzten Agrarlandschaft. [Journal für Ornithologie,
  131(3), 241–265.](https://doi.org/10.1007/BF01640998)
  
- Jeromin, K. (2002). Zur Ernährungsökologie der Feldlerche (Alauda arvensis L. 1758) 
  in der Reproduktionsphase [Doctoral thesis]. 
  [Christian-Albrechts-Universität zu Kiel.](https://macau.uni-kiel.de/receive/diss_mods_00000968)

- Püttmanns et al. (2022). Habitat use and foraging parameters of breeding Skylarks
  indicate no seasonal decrease in food availability in heterogeneous farmland.
  [Ecology and Evolution, 12(1), e8461.](https://doi.org/10.1002/ece3.8461)
